Image Name
  The name of the image.
Image Description
  A description of the image.
Format
  Select the format of the disk from the drop down menu.
Minimum Disk
  Amount of disk space in GB that is required to boot the image.
Minimum RAM
  Amount of RAM in MB that is required to boot the image.
Visibility
  The access permission for the image.
Protected
  If set to 'Yes' then the image cannot be deleted.